@@ -1341,8 +1341,13 @@ class IBVS_sph(VisualServo):
         if self.graphics:
             centre = self.camera.pose.t
             plt.sca(self.ax_3dview)
-            for P in self.P.T:
-                plt.plot(*[(centre[i], P[i]) for i in range(3)], 'k')
+            for (phi, theta), P in zip(p.T, self.P.T):
+                plt.plot(*[(centre[i], P[i]) for i in range(3)], 'k', linewidth=0.5)
+                # pc = [np.sin(theta) * np.cos(phi), np.sin(theta) * np.sin(phi), np.cos(theta)] + centre
+                pc = centre + smbase.unitvec(P - centre)
+                smbase.plot_sphere(0.02, pc, color='r', ax=self.ax_3dview)
+
+                # self.plot_ray(centre, P, color='k')
 
         # update the history variables
         hist = self._history()
@@ -1358,6 +1363,11 @@ class IBVS_sph(VisualServo):
             status = 1
         return status
 
+    def plot_ray(self, centre, P, **kwargs):
+        dir = smbase.unitvec(P - centre)
+        plt.plot(*[(centre[i] + dir[i], P[i]) for i in range(3)], **kwargs)
+
+
     def plot_p(self):
         # result is a vector with row per time step, each row is u1, v1, u2, v2 ...
         for i in range(self.npoints):
