@@ -526,6 +526,8 @@ def luminos(λ, **kwargs):
 
     luminos = loadspectrum(λ, 'photopicluminosity')
 
+    if len(luminos) == 1:
+        luminos = luminos[0]
     return luminos * 683  # photopic luminosity is the Y color matching function
 
 
@@ -563,7 +565,10 @@ def rluminos(λ, **kwargs):
 
     λ = base.getvector(λ)
     xyz = cmfxyz(λ, **kwargs)
-    return xyz[:, 1]  # photopic luminosity is the Y color matching function
+    ret = xyz[:, 1]  # photopic luminosity is the Y color matching function
+    if len(ret) == 1:
+        ret = ret[0]
+    return ret
 
 
 def ccxyz(λ, e=None):
@@ -1043,7 +1048,9 @@ def plot_chromaticity_diagram(colorspace='xy', brightness=1, N=500, alpha=1, blo
     else:
         raise ValueError('bad colorspace')
 
-    plt.show(block=block)
+    if plt.isinteractive() and block is not None:
+        print('plt.show')
+        plt.show(block=block)
     return CS
 
 def plot_spectral_locus(colorspace='xy', labels=True, ax=None, block=False,
@@ -1124,8 +1131,9 @@ def plot_spectral_locus(colorspace='xy', labels=True, ax=None, block=False,
         for i in range(len(λ)):
             ax.text(x[i], y[i], '  {0}'.format(λ[i]))
 
-    plt.show(block=block)
-
+    if plt.isinteractive() and block is not None:
+        print('plt.show')
+        plt.show(block=block)
 
 def cie_primaries():
     """
@@ -1418,15 +1426,14 @@ def gamma_decode(image, gamma='sRGB'):
 
         # normal power law:
         if np.issubdtype(image.dtype, np.floating):
-            return image ** (1.0 / gamma)
+            return image ** gamma
         else:
             # int image
             maxg = np.float32((np.iinfo(image.dtype).max))
-            return ((image.astype(np.float32) / maxg) ** (1 / gamma)) * maxg # original
+            return ((image.astype(np.float32) / maxg) ** gamma) * maxg # original
             # return ((image.astype(np.float32) / maxg) ** gamma) * maxg
         
 
-
 def _srgb_inverse(Rg):
     """
     Inverse sRGB gamma correction
